==> ktp-accounts-kcm-22.04.2.tar.xz: ktp-accounts-kcm-22.04.2/plugins/butterfly/ktpaccountskcm_plugin_butterfly.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Butterfly connection manager.
Comment[bs]=Prilagođena konfiguracija korisničkog naloga pomoću upravitelja Butterfly veze.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Butterfly.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalisat per a comptes que utilisen el gestor de connexions Butterfly.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Butterfly.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Butterfly.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Butterfly-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Butterfly.
Comment[en_GB]=Custom account configuration user interface for accounts using the Butterfly connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Butterfly.
Comment[et]=Butterfly ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Butterfly» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Butterfly-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Butterfly ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Butterfly.
Comment[hu]=Egyedi beállítófelület a Butterfly kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Butterfly.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Butterfly.
Comment[kk]=Butterfly байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់​ខ្លួន​ដោយ​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Butterfly ។
Comment[ko]=Butterfly 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Butterfly ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Butterfly tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Butterfly“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Butterfly verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Butterfly tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Butterfly.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Butterfly.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Butterfly.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Butterfly.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Butterfly.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Butterfly.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Butterfly.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Батерфлај.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Батерфлај.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Butterfly.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Butterfly.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Butterfly.
Comment[tr]=Butterfly bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Butterfly.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Butterfly.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Butterfly connection manager.xx
Comment[zh_CN]=通过 Butterfly 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Butterfly 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_butterfly
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Name=butterfly
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-22.07.80.tar.xz: ktp-accounts-kcm-22.07.80/plugins/butterfly/ktpaccountskcm_plugin_butterfly.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Butterfly connection manager.
Comment[bs]=Prilagođena konfiguracija korisničkog naloga pomoću upravitelja Butterfly veze.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Butterfly.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que utilitzen el gestor de connexions Butterfly.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Butterfly.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Butterfly.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Butterfly-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Butterfly.
Comment[en_GB]=Custom account configuration user interface for accounts using the Butterfly connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Butterfly.
Comment[et]=Butterfly ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Butterfly» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Butterfly-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Butterfly ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Butterfly.
Comment[hu]=Egyedi beállítófelület a Butterfly kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Butterfly.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Butterfly.
Comment[kk]=Butterfly байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់​ខ្លួន​ដោយ​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Butterfly ។
Comment[ko]=Butterfly 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Butterfly ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Butterfly tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Butterfly“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Butterfly verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Butterfly tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Butterfly.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Butterfly.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Butterfly.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Butterfly.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Butterfly.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Butterfly.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Butterfly.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Батерфлај.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Батерфлај.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Butterfly.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Butterfly.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Butterfly.
Comment[tr]=Butterfly bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Butterfly.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Butterfly.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Butterfly connection manager.xx
Comment[zh_CN]=通过 Butterfly 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Butterfly 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_butterfly
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Name=butterfly
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
